==> pfstools_1.6.4.orig.tar.gz: pfstools-1.6.4/src/pfsview/main.h <==
/**
 * @brief 
 * 
 * This file is a part of PFSTOOLS package.
 * ---------------------------------------------------------------------- 
 * Copyright (C) 2003,2004 Rafal Mantiuk and Grzegorz Krawczyk
 * 
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * ---------------------------------------------------------------------- 
 *
 * @author Rafal Mantiuk, <mantiuk@mpi-sb.mpg.de>
 *
 * $Id: main.h,v 1.5 2006/08/09 22:04:54 rafm Exp $
 */

#ifndef MAIN_H
#define MAIN_H

#include <qapplication.h>
#include <qmainwindow.h>
#include <qmessagebox.h>
#include <qlayout.h>
#include <qpopupmenu.h>
#include <qmenubar.h>
#include <qsplitter.h>

#include <list>

#include "pfsview_widget.h"

#define MAX_FRAMES_IN_MEMORY 5

class LuminanceRangeWidget;
class QComboBox;

class pfs::Frame;


enum ColorCoord { CC_RGB = 0, CC_XYZ, CC_Yupvp, CC_Yxy, CC_COUNT
};

class PFSViewMainWin : public QMainWindow {
  Q_OBJECT
public:
    PFSViewMainWin( float window_min, float window_max );
    
public slots:
    void changeClippingMethod( int clippingMethod );
    void updatePointerValue();
    void updateRangeWindow();
    void updateViewSize();
    void updateChannelSelection();
    void setChannelSelection( int selectedChannel );
    void updateZoomValue();
    void gotoNextFrame();
    void gotoPreviousFrame();
    void saveImage();
    void copyImage();
    void setInfNaNTreatment( int method );
    void setNegativeTreatment( int method );
    void setLumMappingMethod( int method );
    void setColorCoord( int method );
    void showAboutdialog();
private:
    void setFrame( pfs::Frame *frame );

    int clippingMethodMI[CLIP_COUNT];
    int infNaNMI[2];
    int negativeMI[NEGATIVE_COUNT];
    
    QPopupMenu *viewMenu;
    QPopupMenu *infnanMenu, *negativeMenu;
    QPopupMenu *colorCoordMenu;
    QPopupMenu *colorClipMenu;
    QLabel *pointerPosAndVal, *zoomValue;
    PFSViewWidget *pfsView;
    LuminanceRangeWidget *lumRange;
    QComboBox *channelSelection;
    QComboBox *mappingMethodCB;
    QStatusBar *statusBar;
    ColorCoord colorCoord;

    bool readNextFrame();

    void updateMenuEnable( );
    
    std::list<pfs::Frame*> frameList;
    std::list<pfs::Frame*>::iterator currentFrame;    
    
public:

    PFSViewWidget *getPFSViewWidget() 
      {
        return pfsView;
      }
    
};

#endif

==> pfstools_1.8.1.orig.tar.gz: pfstools-1.8.1/src/pfsview/main.h <==
/**
 * @brief 
 * 
 * This file is a part of PFSTOOLS package.
 * ---------------------------------------------------------------------- 
 * Copyright (C) 2003,2004 Rafal Mantiuk and Grzegorz Krawczyk
 * 
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * ---------------------------------------------------------------------- 
 *
 * @author Rafal Mantiuk, <mantiuk@mpi-sb.mpg.de>
 *
 * $Id: main.h,v 1.6 2008/10/02 22:42:01 rafm Exp $
 */

#ifndef MAIN_H
#define MAIN_H

#include <qapplication.h>
#include <qmainwindow.h>
#include <qmessagebox.h>
#include <qlayout.h>
#include <qpopupmenu.h>
#include <qmenubar.h>
#include <qsplitter.h>

#include <list>

#include "pfsview_widget.h"

#define MAX_FRAMES_IN_MEMORY 5

class LuminanceRangeWidget;
class QComboBox;

class pfs::Frame;


enum ColorCoord { CC_RGB = 0, CC_XYZ, CC_Yupvp, CC_Yxy, CC_COUNT
};

class PFSViewMainWin : public QMainWindow {
  Q_OBJECT
public:
    PFSViewMainWin( float window_min, float window_max );
    
public slots:
    void changeClippingMethod( int clippingMethod );
    void updatePointerValue();
    void updateRangeWindow();
    void updateViewSize();
    void updateChannelSelection();
    void setChannelSelection( int selectedChannel );
    void updateZoomValue();
    void gotoNextFrame();
    void gotoPreviousFrame();
    void saveImage();
    void copyImage();
    void setInfNaNTreatment( int method );
    void setNegativeTreatment( int method );
    void setLumMappingMethod( int method );
    void setColorCoord( int method );
    void showAboutdialog();
private:
    void setFrame( pfs::Frame *frame );

    int clippingMethodMI[CLIP_COUNT];
    int infNaNMI[2];
    int negativeMI[NEGATIVE_COUNT];
    
    QPopupMenu *viewMenu;
    QPopupMenu *infnanMenu, *negativeMenu;
    QPopupMenu *colorCoordMenu;
    QPopupMenu *colorClipMenu;
    QLabel *pointerPosAndVal, *zoomValue, *exposureValue;
    PFSViewWidget *pfsView;
    LuminanceRangeWidget *lumRange;
    QComboBox *channelSelection;
    QComboBox *mappingMethodCB;
    QStatusBar *statusBar;
    ColorCoord colorCoord;

    bool readNextFrame();

    void updateMenuEnable( );
    
    std::list<pfs::Frame*> frameList;
    std::list<pfs::Frame*>::iterator currentFrame;    
    
public:

    PFSViewWidget *getPFSViewWidget() 
      {
        return pfsView;
      }
    
};

#endif
